\begindata{text,1}
\textdsversion{12}
\define{global
attr:[Justification LeftJustified Point 0]
attr:[LeftMargin LeftEdge Int 16]
attr:[Indent LeftMargin Int -16]
attr:[Flags ContinueIndent Int Set]
attr:[FontFace FixedFace Int Set]
attr:[FontFamily AndyType Int 0]
attr:[Flags TabsCharacters Int Set]}
\enddata{text,1}
