\begindata{text,268718972}
\textdsversion{12}
\define{italic
menu:[Font~1,Italic~11]
attr:[FontFace Italic Int Set]}
\define{bold
menu:[Font~1,Bold~10]
attr:[FontFace Bold Int Set]}
\define{helptopic
menu:[Font~1,Help Topic~50]
attr:[Flags DottedBox Int Set]
attr:[FontFace Bold Int Set]}
\define{invisible
menu:[Font,Invisible~55]
attr:[Flags Hidden Int Set]}
\define{fieldkey
menu:[Font~1,Context Help Keyword~51]}
\define{fieldtxt
menu:[Font~1,Context Help Description~52]}
\define{chapter
menu:[Title~3,Chapter~20]
attr:[Justification Centered Point 0]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[FontFace Bold Int Set]
attr:[FontSize PreviousFontSize Point 4]}
\define{section
menu:[Title~3,Section~21]
attr:[Justification LeftJustified Point 0]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[FontFace Bold Int Set]
attr:[FontSize PreviousFontSize Point 2]}
\define{subsection
menu:[Title~3,Subsection~22]
attr:[Justification LeftJustified Point 0]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[FontFace Bold Int Set]}
\define{paragraph
menu:[Title~3,Paragraph~23]
attr:[Justification LeftJustified Point 0]
attr:[Flags KeepPriorNL Int Set]
attr:[FontFace Italic Int Set]}
\define{bigger
menu:[Font~1,Bigger~20]
attr:[FontSize PreviousFontSize Point 2]}
\define{indent
menu:[Region~4,Indent~20]
attr:[LeftMargin LeftMargin Inch 32768]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]}
\define{typewriter
menu:[Font~1,Typewriter~40]
attr:[FontFace FixedFace Int Set]
attr:[FontFamily AndyType Int 0]}
\define{display
menu:[Region~4,Display~14]
attr:[LeftMargin LeftMargin Inch 32768]
attr:[RightMargin RightMargin Inch 32768]
attr:[Justification LeftJustified Point 0]
attr:[Flags NoFill Int Set]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]}
\define{example
menu:[Region~4,Example~12]
attr:[LeftMargin LeftMargin Inch 32768]
attr:[Justification LeftJustified Point 0]
attr:[Flags NoFill Int Set]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[FontFace FixedFace Int Set]
attr:[FontFamily AndyType Int 0]}
\define{description
menu:[Region~4,Description~11]
attr:[LeftMargin LeftMargin Cm 187268]
attr:[Indent LeftMargin Cm -187269]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]}
\define{secondleveldescription
menu:[Region~4,SecondLevelDescription~12]
attr:[LeftMargin LeftMargin Cm 356041]
attr:[Indent LeftMargin Cm -83230]}
\define{quotation
menu:[Region~4,Quotation~10]
attr:[LeftMargin LeftMargin Inch 32768]
attr:[RightMargin RightMargin Inch 32768]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[FontFace Italic Int Set]}
\define{subscript
menu:[Font~1,Subscript~30]
attr:[Script PreviousScriptMovement Point 2]
attr:[FontSize PreviousFontSize Point -2]}
\define{superscript
menu:[Font~1,Superscript~13]
attr:[Script PreviousScriptMovement Point -6]
attr:[FontSize PreviousFontSize Point -2]}
\define{smaller
menu:[Font~1,Smaller~21]
attr:[FontSize PreviousFontSize Point -2]}
\define{heading
menu:[Title~3,Heading~11]
attr:[LeftMargin LeftMargin Inch -13107]
attr:[Justification LeftJustified Point 0]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[FontFace Bold Int Set]}
\define{majorheading
menu:[Title~3,MajorHeading~10]
attr:[Justification Centered Point 0]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[FontSize PreviousFontSize Point 4]}
\define{formatnote
menu:[Region~4,FormatNote~60]
attr:[Flags PassThru Int Set]
attr:[Flags NoFill Int Set]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]}
\define{subheading
menu:[Title~3,Subheading~12]
attr:[Justification LeftJustified Point 0]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[FontFace Bold Int Set]}
\define{center
menu:[Justify~2,Center~10]
attr:[Justification Centered Point 0]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]}
\define{flushleft
menu:[Justify~2,FlushLeft~20]
attr:[Justification LeftJustified Point 0]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]}
\define{flushright
menu:[Justify~2,FlushRight~21]
attr:[Justification RightJustified Point 0]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]}
\define{leftindent
menu:[Region~4,LeftIndent~21]
attr:[LeftMargin LeftMargin Inch 32768]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]}
\define{programexample
menu:[Region~4,ProgramExample~13]
attr:[LeftMargin LeftMargin Inch 32768]
attr:[Justification LeftJustified Point 0]
attr:[Flags NoFill Int Set]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[FontFace FixedFace Int Set]
attr:[FontFamily AndyType Int 0]}
\define{underline
menu:[Font~1,Underline~41]
attr:[Flags Underline Int Set]}
\define{formattingnote
menu:[Region,FormattingNote]
attr:[Flags PassThru Int Set]
attr:[Flags NoFill Int Set]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]}
\define{strikethrough
menu:[Font~1,Strike Through~42]
attr:[Flags StrikeThrough Int Set]}
\define{changebar
menu:[Font~1,Change Bar~43]
attr:[Flags ChangeBar Int Set]}
\chapter{<@name@>: Short Phrase Describing  It

}
\section{What <@name@> is

}\leftindent{
One or two sentences on what the application does.  Comparable to the first 
part of the Description section of man pages.

}
\section{Starting <@name@>

}\leftindent{
Introductory section that can duplicate some material in the Quick Reference 
section.  Designed to get the user up and going quickly with the app.  Can be 
omitted, especially from help for applications with which the end user does 
not interact.  Feel free to move the Quick Reference section to here and leave 
out Starting it.

}
\section{Warnings

}\leftindent{
Things that might unpleasantly surprise the user.

}
\section{Icon Meanings or Attributes or Commands

}\leftindent{
This category varies with the application; in general, it's the base set of 
things you can order the application to do, whether embodied in icons or in 
command lines.

}
\section{Pop-up menu meanings

}\leftindent{
What do the menu options do?

}
\section{The <@name@> window, Output, Objects, Regions, How <@name@> works, 
Using <@name@>, <@name@> Concepts, Including <@name@> pictures in documents, 
Subscribing to bulletin boards, The default <@name@>, Preferences, Programming 
<@name@>

}\leftindent{
These are miscellaneous headings relevant to particular kinds of applications. 
 Some will appear in some help texts, some help texts will not contain any, 
and no help text will contain them all.

}
\section{Quick reference

}\leftindent{
Includes a syntax summary, a quick list of options and arguments, and 
miscellaneous short notes on operating the application.  This is a stripped 
version of a complete man page except for pop-up menus and icons.

}
\section{Program Author}

\leftindent{
Name of the author of the program if desired.  }


\section{Recent changes to <@name@>

}\leftindent{
A place for programmers to record what changes they've made to the software. 
 These will eventually be incorporated by the documenter into the other 
sections.

}
\section{Advice

}\leftindent{
How to get there from here; procedural instructions for accomplishing common 
tasks using the application.  This section will be compiled partly by the 
documenter and partly by the user community at large, who should feel free to 
contribute their pet tasks and how to do them.

}
\section{Related tools}  


\leftindent{Move your mouse cursor to one of the following names and click 
your left mouse button to see the help file for:


\leftindent{Names of other programs, in a vertical list, no commas or other 
punctuation marks, with the Help Topic style from the Font menu card added 
separately to each entry \
}}\enddata{text,268718972}
