\begindata{text, 1}
\textdsversion{12}
\define{indent1
menu:[Indent~5,Indent +1cm~1]
attr:[LeftMargin LeftMargin Cm 69358]}
\define{indent2
menu:[Indent~5,Indent +2cm~2]
attr:[LeftMargin LeftMargin Cm 138716]}
\define{indent4
menu:[Indent~5,Indent +4cm~3]
attr:[LeftMargin LeftMargin Cm 277432]}
\define{indent8
menu:[Indent~5,Indent +8cm~4]
attr:[LeftMargin LeftMargin Cm 554864]}
\define{indent16
menu:[Indent~5,Indent +16cm~5]
attr:[LeftMargin LeftMargin Cm 1109728]}
\define{tempindent1
menu:[Indent~5,Temp Indent +1cm~10]
attr:[Indent PreviousIndentation Cm 69358]}
\define{tempindent2
menu:[Indent~5,Temp Indent +2cm~11]
attr:[Indent PreviousIndentation Cm 138716]}
\define{tempindent4
menu:[Indent~5,Temp Indent +4cm~12]
attr:[Indent PreviousIndentation Cm 277432]}
\define{tempindent8
menu:[Indent~5,Temp Indent +8cm~13]
attr:[Indent PreviousIndentation Cm 554864]}
\define{tempindent16
menu:[Indent~5,Temp Indent +16cm~14]
attr:[Indent PreviousIndentation Cm 1109728]}
\define{tempindentneg1
menu:[Indent~5,Temp Indent -1cm~20]
attr:[Indent PreviousIndentation Cm -69358]}
\define{tempindentneg2
menu:[Indent~5,Temp Indent -2cm~21]
attr:[Indent PreviousIndentation Cm -138716]}
\define{tempindentneg4
menu:[Indent~5,Temp Indent -4cm~22]
attr:[Indent PreviousIndentation Cm -277432]}
\define{tempindentneg8
menu:[Indent~5,Temp Indent -8cm~23]
attr:[Indent PreviousIndentation Cm -554864]}
\define{tempindentneg16
menu:[Indent~5,Temp Indent -16cm~24]
attr:[Indent PreviousIndentation Cm -1109728]}
\define{italic
menu:[Font~1,Italic~11]
attr:[FontFace Italic Int Set]}
\define{bold
menu:[Font~1,Bold~10]
attr:[FontFace Bold Int Set]}
\define{chapter
menu:[Title~3,Chapter~20]
attr:[Justification LeftJustified Point 0]
attr:[FontFace Bold Int Set]
attr:[FontSize PreviousFontSize Point 4]}
\define{section
menu:[Title~3,Section~21]
attr:[Justification LeftJustified Point 0]
attr:[FontFace Bold Int Set]
attr:[FontSize PreviousFontSize Point 2]}
\define{subsection
menu:[Title~3,Subsection~22]
attr:[Justification LeftJustified Point 0]
attr:[FontFace Bold Int Set]}
\define{paragraph
menu:[Title~3,Paragraph~23]
attr:[Justification LeftJustified Point 0]
attr:[FontFace Italic Int Set]}
\define{bigger
menu:[Font~1,Bigger~20]
attr:[FontSize PreviousFontSize Point 2]}
\define{indent
menu:[Region~4,Indent~20]
attr:[LeftMargin LeftMargin Inch 32768]
attr:[RightMargin RightMargin Inch 32768]}
\define{typewriter
menu:[Font~1,Typewriter~40]
attr:[FontFace FixedFace Int Set]
attr:[FontFamily AndyType Int 0]}
\define{display
menu:[Region~4,Display~14]
attr:[LeftMargin LeftMargin Inch 32768]
attr:[RightMargin RightMargin Inch 32768]
attr:[Justification LeftJustified Point 0]}
\define{example
menu:[Region~4,Example~12]
attr:[LeftMargin LeftMargin Inch 32768]
attr:[Justification LeftJustified Point 0]
attr:[FontFace FixedFace Int Set]
attr:[FontFamily AndyType Int 0]}
\define{description
menu:[Region~4,Description~11]
attr:[LeftMargin LeftMargin Inch 32768]
attr:[Indent LeftMargin Inch -32768]}
\define{quotation
menu:[Region~4,Quotation~10]
attr:[LeftMargin LeftMargin Inch 32768]
attr:[RightMargin RightMargin Inch 32768]
attr:[FontFace Italic Int Set]}
\define{subscript
menu:[Font~1,Subscript~30]
attr:[Script PreviousScriptMovement Point 2]
attr:[FontSize PreviousFontSize Point -2]}
\define{superscript
menu:[Font~1,Superscript~31]
attr:[Script PreviousScriptMovement Point -6]
attr:[FontSize PreviousFontSize Point -2]}
\define{smaller
menu:[Font~1,Smaller~21]
attr:[FontSize PreviousFontSize Point -2]}
\define{heading
menu:[Title~3,Heading~11]
attr:[LeftMargin LeftMargin Inch -13107]
attr:[Justification LeftJustified Point 0]
attr:[FontFace Bold Int Set]}
\define{majorheading
menu:[Title~3,MajorHeading~10]
attr:[Justification Centered Point 0]
attr:[FontSize PreviousFontSize Point 4]}
\define{formatnote
menu:[Region~4,FormatNote~60]
attr:[Flags PassThru Int Set]}
\define{subheading
menu:[Title~3,Subheading~12]
attr:[Justification LeftJustified Point 0]
attr:[FontFace Bold Int Set]}
\define{center
menu:[Justify~2,Center~10]
attr:[Justification Centered Point 0]}
\define{flushleft
menu:[Justify~2,FlushLeft~20]
attr:[Justification LeftJustified Point 0]}
\define{flushright
menu:[Justify~2,FlushRight~21]
attr:[Justification RightJustified Point 0]}
\define{leftindent
menu:[Region~4,LeftIndent~21]
attr:[LeftMargin LeftMargin Inch 32768]}
\define{underline
menu:[Font~1,Underline~10]
attr:[FontFace Underline Int Set]}
\enddata{text,1}
