\begindata{text, 1}
\textdsversion{12}
\define{comment
attr:[FontFace Italic Int Set]
attr:[FontFace FixedFace Int Clear]
attr:[FontSize PreviousFontSize Point 2]
attr:[FontFamily Andy Int 0]}
\define{function
attr:[FontFace Bold Int Set]}
\define{global
attr:[FontFace FixedFace Int Set]
attr:[Justification LeftJustified Point 0]
attr:[LeftMargin LeftEdge Int 16]
attr:[Indent LeftMargin Int -16]
attr:[Flags ContinueIndent Int Set]
attr:[FontSize ConstantFontSize Point 10]
attr:[FontFamily AndyType Int 0]}
\enddata{text,1}
