\begindata{text,537852636}
\textdsversion{12}
\define{bold

attr:[FontFace Bold Int Set]}
\define{prefname

attr:[Tabs TabClear Point 108]
attr:[Tabs TabClear Point 72]
attr:[Tabs TabClear Point 36]
attr:[Flags Underline Int Set]
attr:[FontFace Bold Int Set]
attr:[FontSize PreviousFontSize Point 2]}
\define{global

attr:[Tabs TabClear Point 36]
attr:[Tabs TabClear Point 108]
attr:[Tabs TabClear Point 72]}
\define{italic

attr:[FontFace Italic Int Set]}
\define{groupname

attr:[Flags DottedBox Int Set]}
\enddata{text,537852636}
