\begindata{text,268656896}
\textdsversion{12}
\define{italic
menu:[Font~1,Italic~11]
attr:[FontFace Italic Int Set]}
\define{bold
menu:[Font~1,Bold~10]
attr:[FontFace Bold Int Set]}
\define{chapter
menu:[Title~3,Chapter~20]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[Justification Centered Point 0]
attr:[FontFace Bold Int Set]
attr:[FontSize PreviousFontSize Point 4]}
\define{section
menu:[Title~3,Section~21]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[Justification LeftJustified Point 0]
attr:[FontFace Bold Int Set]
attr:[FontSize PreviousFontSize Point 2]}
\define{subsection
menu:[Title~3,Subsection~22]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[Justification LeftJustified Point 0]
attr:[FontFace Bold Int Set]}
\define{paragraph
menu:[Title~3,Paragraph~23]
attr:[Flags KeepPriorNL Int Set]
attr:[Justification LeftJustified Point 0]
attr:[FontFace Italic Int Set]}
\define{bigger
menu:[Font~1,Bigger~20]
attr:[FontSize PreviousFontSize Point 2]}
\define{indent
menu:[Region~4,Indent~20]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[LeftMargin LeftMargin Inch 32768]}
\define{typewriter
menu:[Font~1,Typewriter~40]
attr:[FontFace FixedFace Int Set]
attr:[FontFamily AndyType Int 0]}
\define{display
menu:[Region~4,Display~14]
attr:[Flags NoFill Int Set]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[LeftMargin LeftMargin Inch 32768]
attr:[RightMargin RightMargin Inch 32768]
attr:[Justification LeftJustified Point 0]}
\define{example
menu:[Region~4,Example~12]
attr:[Flags NoFill Int Set]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[LeftMargin LeftMargin Inch 32768]
attr:[Justification LeftJustified Point 0]
attr:[FontFace FixedFace Int Set]
attr:[FontFamily AndyType Int 0]}
\define{description
menu:[Region~4,Description~11]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[LeftMargin LeftMargin Inch 32768]
attr:[Indent LeftMargin Inch -32768]}
\define{quotation
menu:[Region~4,Quotation~10]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[LeftMargin LeftMargin Inch 32768]
attr:[RightMargin RightMargin Inch 32768]
attr:[FontFace Italic Int Set]}
\define{subscript
menu:[Font~1,Subscript~30]
attr:[Script PreviousScriptMovement Point 2]
attr:[FontSize PreviousFontSize Point -2]}
\define{superscript
menu:[Font~1,Superscript~13]
attr:[Script PreviousScriptMovement Point -6]
attr:[FontSize PreviousFontSize Point -2]}
\define{smaller
menu:[Font~1,Smaller~21]
attr:[FontSize PreviousFontSize Point -2]}
\define{heading
menu:[Title~3,Heading~11]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[LeftMargin LeftMargin Inch -13107]
attr:[Justification LeftJustified Point 0]
attr:[FontFace Bold Int Set]}
\define{majorheading
menu:[Title~3,MajorHeading~10]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[Justification Centered Point 0]
attr:[FontSize PreviousFontSize Point 4]}
\define{formatnote
menu:[Region~4,FormatNote~60]
attr:[Flags NoFill Int Set]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[Flags PassThru Int Set]}
\define{subheading
menu:[Title~3,Subheading~12]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[Justification LeftJustified Point 0]
attr:[FontFace Bold Int Set]}
\define{center
menu:[Justify~2,Center~10]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[Justification Centered Point 0]}
\define{flushleft
menu:[Justify~2,FlushLeft~20]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[Justification LeftJustified Point 0]}
\define{flushright
menu:[Justify~2,FlushRight~21]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[Justification RightJustified Point 0]}
\define{leftindent
menu:[Region~4,LeftIndent~21]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[LeftMargin LeftMargin Inch 32768]}
\define{programexample
menu:[Region~4,ProgramExample~13]
attr:[Flags NoFill Int Set]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[LeftMargin LeftMargin Inch 32768]
attr:[Justification LeftJustified Point 0]
attr:[FontFace FixedFace Int Set]
attr:[FontFamily AndyType Int 0]}
\define{underline
menu:[Font~1,Underline~41]
attr:[Flags Underline Int Set]}
\define{strikethrough
menu:[Font~1,Strike Through~42]
attr:[Flags StrikeThrough Int Set]}
\define{changebar
menu:[Font~1,Change Bar~43]
attr:[Flags ChangeBar Int Set]}
\define{formattingnote
menu:[Region,FormattingNote]
attr:[Flags NoFill Int Set]
attr:[Flags KeepPriorNL Int Set]
attr:[Flags KeepNextNL Int Set]
attr:[Flags PassThru Int Set]}
\define{keyword
menu:[Title~3,Keyword]
attr:[FontFace Italic Int Set]}
\chapter{Name of Application: Short Phrase Describing  It


}Short\leftindent{ }introductory paragraph.  Unless the document is very 
short, explain in one or two sentences the general purpose of the help 
document (ie. an introduction, a detailed description, a tutorial, a reference 
document).  Also include any caveats about the program/process to be 
discussed.  Finish with a list of all the relevant sections that are included, 
as in the following example:


\leftindent{This help document includes the following sections:


\leftindent{What < is

Starting <

Warnings

Pop-up menu meanings

Quick reference

Related tools}}


\bold{Important Note:}  In this and the following sections of a help file, use 
these general guidelines:


\leftindent{1) Format pop-up menu \bold{options} with bold style.


2) Format pop-up menu \italic{titles} with italic style.


3) Format help  \keyword{keywords}  with \bold{Keyword} style on the 
\italic{Title} menu card and separate them from the running text with two 
spaces on either side.

}
\section{What < is

}\leftindent{
One or two sentences on what the application does.  Comparable to the first 
part of the Description section of man pages.

}
\section{Starting <

}\leftindent{
Introductory section that can duplicate some material in the Quick Reference 
section.  Designed to get the user up and going quickly with the application. 
 Can be omitted, especially from help for applications with which the end user 
does not interact.  Feel free to move the Quick Reference section to here and 
leave out Starting it.

}
\section{Warnings

}\leftindent{
Things that might unpleasantly surprise the user.

}
\section{Icon Meanings or Attributes or Commands

}\leftindent{
This category varies with the application; in general, it's the base set of 
things you can order the application to do, whether embodied in icons or in 
command lines.

}
\section{Pop-up menu meanings

}\leftindent{
What do the menu options do?

}
\section{The < window, Output, Objects, Regions, How < works, Using <, < 
Concepts, Including < pictures in documents, Subscribing to bulletin boards, 
The default <, Preferences, Programming <

}\leftindent{
These are miscellaneous headings relevant to particular kinds of applications. 
 Some will appear in some help texts, some help texts will not contain any, 
and no help text will contain them all.

}
\section{Quick reference

}\leftindent{
Includes a syntax summary, a quick list of options and arguments, and 
miscellaneous short notes on operating the application.  This is a stripped 
version of a complete man page except for pop-up menus and icons.

}
\section{Program Author}

\leftindent{
Name of the author of the program if desired.  }


\section{Recent changes to <

}\leftindent{
A place for programmers to record what changes they've made to the software. 
 These will eventually be incorporated by the documenter into the other 
sections.

}
\section{Advice

}\leftindent{
How to get there from here; procedural instructions for accomplishing common 
tasks using the application.  This section will be compiled partly by the 
documenter and partly by the user community at large, who should feel free to 
contribute their pet tasks and how to do them.

}
\section{Related tools}  


Select (highlight) one of the italicized names and choose "Show Help on 
Selected Word" from the front pop-up menu to see the help file for:


\leftindent{Here, place the names of other help keywords in a vertical, 
left-indented list.  Format the list with Keyword style and do not use commas 
or any other punctuation marks.\
}\enddata{text,268656896}
