.\" This file uses -man macros.
.\"
.TH VICEXX 1 "Sept 15, 1987" " "
.SH NAME
name in lowercase i.e. vicexx \- quick description of command or function
.SH SYNOPSIS
.BR vicexx filename
.\" Use the B, I, BR, or BI tags to show syntax.
.SH DESCRIPTION
Describe the command or function in detail.  Put the
name in
.I italic
and the number in roman:
.IR vicexx (1).
Use only simple paragraph constructions.  Avoid bulleted,
numbered, or other hanging style lists.  For a simple list
at the margin, use the troff break (\.br) tag:
.br
aaaaaaa
.br
bbbbbbb
.br
ccccccc
.PP
Delete any sections that are not needed.  Only NAME, SYNOPSIS, and
DESCRIPTION are required.
.SH "EXAMPLES"
.PP
Put one or two examples here.
.SH "FORMAT"
.PP
Not often used, but available show format of file, complex variable, etc.
.SH "NOTES"
.PP
Use for important information you want to make sure the reader
sees.
.SH "FILES"
.PP
List the file files that the command or function uses.
.SH "SEE ALSO"
.PP
List related command or functions here.  Use normal body font in
this section:
ecvt(3),
putc(3S),
scanf(3S)
.SH "DIAGNOSTICS"
.PP
Describe the diagnostic indicators the program produces, such
as return codes, error messages, expletives, etc.
.SH "BUGS"
.PP
Describe any know problems and circumstances of psychopathic
behavior.
